@@ -139,24 +139,32 @@ print.bootci4print <- function(x, ...) {
   }
 }
 
+.inRstudio <- function(silent=FALSE, bool=TRUE) {
+  trygetfn <- try(get("getActiveProject",envir = asNamespace("rstudioapi")), silent=silent) # fails if rstudioapi not installed
+  if ( tryres <- ( ! inherits(trygetfn,"try-error"))) {
+    tryres <- try(trygetfn(), silent=silent) # fails if rstudioapi not running ie not an Rstudio session
+    # otherwise NULL if no active project, or the path if there is an active project.
+  }
+  if (bool) tryres <- ! inherits(tryres,"try-error") # to return a boolean : whether we are in an Rstudio session or not
+  # otherwise retuen value is (try-error, or NULL, or path).
+  tryres 
+}
 
 projpath <- local({
   pp <- NULL
   function() {
     if (is.null(ppp <- .spaMM.data$options$projpath)) {
       if (is.null(pp)) {
-        tryres <- try(get("getActiveProject",envir = asNamespace("rstudioapi"))) # fails if rstudioapi not installed
-        if ( ! inherits(tryres,"try-error")) tryres <- try(tryres()) # fails if package not running ie not an Rstudio session
-        if (inherits(tryres,"try-error")) {
+        projpathinRstudio <- .inRstudio(silent=FALSE, bool=FALSE)
+        if (inherits(projpathinRstudio,"try-error") || is.null(projpathinRstudio)) { # not an Rstudio session || no active project
           if (interactive()) {
             message('Need to give the project path, say "C:/home/francois/travail/stats/spaMMplus/spaMM":')
-            tryres <- readline(prompt="Enter path: ")
+            pp <<- readline(prompt="Enter path: ")
           } else {
             message('Need to start in the projpath, say "C:/home/francois/travail/stats/spaMMplus/spaMM", so that getwd() finds it.')
-            tryres <- getwd()
+            pp <<- getwd()
           }
-        } 
-        pp <<- tryres
+        } else pp <<- projpathinRstudio
       }
       return(pp)
     } else return(ppp)
